/*
 * Copyright (c) 2002 Michal Moskal <malekith@pld-linux.org>
 * All rights reserved. See file COPYRIGHT for details about licensing.
 *
 * $Rev: 988 $ $LastChangedDate: 2002-09-15 12:23:51 +0200 (Sun, 15 Sep 2002) $
 *
 * Lexer - wrapper around Gontlex.
 */
 
open Ast;
open Util;

struct t {
    string filename;
    <int, int>Gontlex::t lex;
}

<int, int>Gontlex::mode m = Gontlex::make_mode();

def make_lexer(fn)
    ({lex = Gontlex::of_genlex(m, Genlex::of_stream(Stdio::fopen(fn, "r"))),
      filename = fn})
	
def get_token(c)
{
    def make_loc()
    {
	_ l = {file = c.filename, 
	       first_line = 0, first_column = 0,
	       last_line = 0, last_column = 0};
	(l.first_line, l.first_column) = Gontlex::beg_location(c.lex);
	(l.last_line, l.last_column) = Gontlex::end_location(c.lex);
	return l;
    }
    
    try {
	_ r;
	switch Gontlex::get_token(c.lex) {
	case Gontlex::Id(s):		r = Parser::ID(s);
	case Gontlex::String(s):	r = Parser::STRING(s);
	case Gontlex::Char(c):		r = Parser::CHAR(int_of_char(c));
	case Gontlex::Int(s):		r = Parser::INT(s);
	case Gontlex::Float(s):		r = Parser::FLOAT(s);
	case Gontlex::Ty_var(s):	r = Parser::TYVAR(s);
	case Gontlex::Keyword(k):	r = Parser::Keyword(k);
	case Gontlex::Operator(k):	r = Parser::Operator(k);
	case Gontlex::Eof:		r = Parser::Eof;
	
	case Gontlex::Comment(_):
	case Gontlex::Blank(_):
	    return ice("Lexer::get_token(): comment or blank from lexer");
	}

	return (r, make_loc());
    } with {
    case Gontlex::Error(m):
	errorl(make_loc(), "lexical error: " + 	m);
	return get_token(c);
    }
}

section init
{
    List::iter(fun (p) {let (n, i) = p in Gontlex::add_operator(m, n, i);},
	       Parser::operators);
    List::iter(fun (p) {let (n, i) = p in Gontlex::add_keyword(m, n, i);},
	       Parser::keywords);
    Gontlex::handle_tyvars(m);
}

// vim:sts=4:sw=4
