" Vim syntax file
" Language:    Gont
" Maintainer:  Michal Moskal <malekith@pld-linux.org>
" Last Change: $LastChangedDate: 2002-09-12 21:19:50 +0200 (Thu, 12 Sep 2002) $
" Version:     1.01
" Revision:    $Rev: 941 $

" To use this file, copy it to ~/.vim/syntax and enter the following to
" ~/.vim/filetype.vim:
"
"	augroup filetypedetect
"		autocmd BufNewfile,BufRead *.g,*.gi setfiletype gont
"	augroup END
"
" Since gontc assumes utf-8 encoding of input files, you can add following
" to your ~/.vimrc file:
"
"	augroup gont
"		au!
"		autocmd BufNewfile,BufReadPre *.g,*.gi 
"			\ set fencs=utf-8,iso-8859-2 fenc=utf-8
"	augroup END
"
" Have fun :)

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

" in fact char ain't keyword, nor option and list are... 
syn keyword gontType float int bool void string char option list

syn keyword gontKeyword break case continue do else extern finally for fun
syn keyword gontKeyword if in let local open opt_struct raise return skip 
syn keyword gontKeyword struct switch as def
syn keyword gontKeyword try typedef type union while with exception section

syn keyword gontConst null true false

syn match	gontSpec	"[()\]\[]\|\*\["
syn match	gontNumber "0[xX][0-9a-fA-F]\+"
syn match	gontNumber "0[bB][01]\+"
syn match	gontNumber "0[oO][0-7]\+"
syn match	gontNumber "[0-9]\+\((\.[0-9]*)\)\?\([eE]\([+-]\)\?[0-9]*\)\?"

syn match	gontTyVar	"'[a-zA-Z_][a-zA-Z_0-9]*"
syn match	gontChar	"'\(.\|\\.\|\\x\x\x\)'"

syn match	gontUIdentifier	"[A-Z][a-zA-Z_0-9]*"
syn match	gontIdentifier	"[a-z_][a-zA-Z_0-9]*"

syn match	gontTyArg	"[<>]"

" Comments
syn keyword gontTodo	contained	XXX TODO FIXME
syn cluster gontCommentGroup	contains=gontTodo
syn match gontComment	"//.*$"	contains=@gontCommentGroup
syn region gontComment start="/\*" end="\*/" contains=@gontCommentGroup

syn match	gontModPrefix	"[A-Za-z_][a-zA-Z_0-9]*::"

syn match	gontSpecial	display contained "\\\(x\x\x\|.\|$\)"
syn region	gontString	start=+L\="+ skip=+\\\\\|\\"+ end=+"+ contains=gontSpecial

" synchronization
syn sync lines=500

" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_gont_syntax_inits")
  if version < 508
    let did_lisp_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

"  HiLink gontIdentifier	Identifier
  HiLink gontUIdentifier	Constant
  HiLink gontModPrefix	Include
  HiLink gontComment	Comment
  HiLink gontKeyword	Statement
  HiLink gontString	String
  HiLink gontChar	Character
  HiLink gontType	Type
  HiLink gontMacro	Macro
  HiLink gontSpec	Special
  HiLink gontTyVar	Special
  HiLink gontNumber	Number
  HiLink gontConst	Keyword
  HiLink gontTodo	Todo
  
  HiLink gontTyArg	Type

" HiLink	gontErrInParen	Error
" HiLink	gontErrInBracket	Error
  delcommand HiLink
endif

let b:current_syntax = "gont"

" vim: nowrap
